#!/bin/bash
# Maintainer: Pierrick LE BRUN <akuna@free.fr>
#
# Homepage: http://ipw2100.sourceforge.net and http://ipw2200.sourceforge.net
#
# This package include both firmware code.

check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	for COMPLETED in $package.{tgz,md5,dep}; do
		if [ "$KEEPDEPFILE" = "1" ] && [ $COMPLETED = $package.dep ]; then
			continue
		elif [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}

set_post_permissions() {
	[ -d $startdir/pkg/usr/bin ] && find $startdir/pkg/usr/bin -user root -group bin -exec chown root:root {} \;
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
}

create_package() {
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.tgz
	cd $startdir
	md5sum $package.tgz > $startdir/$package.md5
}

prepare_directory() {
	mkdir -p $startdir/src/$pkgname-$pkgver
}

build() {
	cd $startdir 
	tar xvzfC ipw2100-fw-1.3.tgz $startdir/src/$pkgname-$pkgver
	tar xvzfC ipw2200-fw-3.0.tgz $startdir/src/$pkgname-$pkgver
	mkdir -p $startdir/pkg/etc/licences.d
	touch $startdir/pkg/etc/licences.d/ipw2x00fw
	printf "LICENCE NAME: INTEL(C) SOFTWARE LICENCE AGREEMENT FOR IPW2100 and IPW2200 FIRMWARE \n" > $startdir/pkg/etc/licences.d/ipw2x00fw
	printf "LICENCED PACKAGES: ipw2x00fw \n" >> $startdir/pkg/etc/licences.d/ipw2x00fw
	printf " \n" >> $startdir/pkg/etc/licences.d/ipw2x00fw
	printf "INTEL(C) SOFTWARE LICENCE AGREEMENT FOR IPW2100 FIRMWARE \n" >> $startdir/pkg/etc/licences.d/ipw2x00fw
	printf " \n" >> $startdir/pkg/etc/licences.d/ipw2x00fw
	cat $startdir/src/$pkgname-$pkgver/LICENSE >> $startdir/pkg/etc/licences.d/ipw2x00fw
	printf "INTEL(C) SOFTWARE LICENCE AGREEMENT FOR IPW2200 FIRMWARE \n" >> $startdir/pkg/etc/licences.d/ipw2x00fw
	printf " \n" >> $startdir/pkg/etc/licences.d/ipw2x00fw
	cat $startdir/src/$pkgname-$pkgver/*/LICENSE* >> $startdir/pkg/etc/licences.d/ipw2x00fw
	mkdir -p $startdir/pkg/lib/firmware
	cp $startdir/src/$pkgname-$pkgver/* $startdir/pkg/lib/firmware
	cp $startdir/src/$pkgname-$pkgver/*/* $startdir/pkg/lib/firmware
} 

create_slackdesc() {
mkdir -p $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
ipw2x00fw: Intel® PRO/Wireless 2x00 Firmware for Linux
ipw2x00fw:
ipw2x00fw: For both ipw2100 & ipw2200.
ipw2x00fw: Firmware images to be loaded in order for the drivers
ipw2x00fw: to function. While the drivers themselves are GPL, the
ipw2x00fw: microcodes are not, but can be used for free, so long as
ipw2x00fw: Intel Software License agreement from Intel are kept
ipw2x00fw: alongside & are read & agreed by the end user.
ipw2x00fw: 
ipw2x00fw: 
ipw2x00fw: 
EODESC
}

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=ipw2x00fw
pkgver=1.0
pkgrel=1
zenver=52
arch=noarch
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel

#Execution

check_for_root
clean_old_builds
prepare_directory
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
set_post_permissions
copy_build_script
create_package
echo "Package has been built."
